==> darcs_2.12.4.orig.tar.gz: darcs-2.12.4/tests/rebase-unsuspend-to-patch.sh <==
#!/bin/sh -e
##
## Test rebase unsuspend --to-patch
##
## Copyright (C) 2011 Ganesh Sittampalam
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib

rm -rf R
mkdir R
cd R
darcs init
touch foo
darcs rec -lam 'add foo'

touch bar
darcs rec -lam 'add bar'

touch baz
darcs rec -lam 'add baz'

echo 'yyyy' | darcs rebase suspend

darcs rebase unsuspend --to-patch 'bar' -a
darcs changes | grep 'add foo'
darcs changes | grep 'add bar'
darcs changes | not grep 'add baz'

==> darcs_2.18.4.orig.tar.gz: darcs-2.18.4/tests/rebase-unsuspend-to-patch.sh <==
#!/bin/sh -e
##
## Test rebase unsuspend --to-patch
##
## Copyright (C) 2011 Ganesh Sittampalam
##
## Permission is hereby granted, free of charge, to any person
## obtaining a copy of this software and associated documentation
## files (the "Software"), to deal in the Software without
## restriction, including without limitation the rights to use, copy,
## modify, merge, publish, distribute, sublicense, and/or sell copies
## of the Software, and to permit persons to whom the Software is
## furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be
## included in all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
## EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
## MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
## NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
## BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
## ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
## CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
## SOFTWARE.

. lib

rm -rf R
mkdir R
cd R
darcs init
touch foo
darcs rec -lam 'add foo'

touch bar
darcs rec -lam 'add bar'

touch baz
darcs rec -lam 'add baz'

echo 'yyyy' | darcs rebase suspend

darcs rebase unsuspend --to-patch 'bar' -a 2>log
darcs changes | grep 'add foo'
darcs changes | grep 'add bar'
darcs changes | not grep 'add baz'
grep "1 suspended patch" log
